@@ -64,17 +64,14 @@ class BottleClient:
         self._connected = False
         self.genome = None
         self.genie = None
-        self.local = False
         self.send_unique_ids = True
         self.summarize_for_single_node = False
         if 'secure' not in self.bottle_info or self.bottle_info['secure']:
             self.secure = True
+            self.url = 'https://{name}.{domain}/'.format(**self.bottle_info)
         else:
             self.secure = False
-        self.url = 'https://{name}.{domain}/'.format(**self.bottle_info)
-        if 'local' in self.bottle_info and self.bottle_info['local']:
-            self.url = 'http://localhost/'
-            self.local = True
+            self.url = 'http://{name}.{domain}/'.format(**self.bottle_info)
 
     def __repr__(self) -> str:
         return '<{name}.{domain}| secure: %r, connected: %s, genie: %s, \
@@ -117,8 +114,6 @@ class BottleClient:
         self.query_nodes = [{'id': self.genome.primitive_map[node], 'name': node} for node in nodes]
         return self.query_nodes
 
-
-
     def _query(self, query_method: Any, path: str, data: Dict = None, nodes: List = None, unique_id: str = None) -> List:
         """Internal helper function to make an RPC call with the given *query* and *data*."""
         if not self._connected:
@@ -195,7 +190,7 @@ class BottleClient:
         """Return the current status of the bottle."""
         if nodes is None:
             nodes = self.all_nodes
-        return self._query(requests.get, '/status', nodes=nodes)
+        return self._query(requests.get, 'status', nodes=nodes)
 
     def learn(self, nodes: List = None) -> List:
         """Return the learn results."""
@@ -217,7 +212,7 @@ class BottleClient:
 
     def get_hive_prediction_utility(self) -> dict:
         """Return prediction result data."""
-        return requests.get(
+        return requests.post(
             f'{self.url}predictions/utility',
             headers=self.headers,
             json={'data': {'primitive_ids': [primitive['id'] for primitive in self.query_nodes]}}).json()
@@ -424,43 +419,51 @@ class BottleClient:
     def start_acting(self, nodes: List = None) -> List[Dict[str, Any]]:
         """
         Allow query nodes to start acting.
-
-        TODO: Should user be able to specify which nodes.
         """
         if nodes is None:
             nodes = self.query_nodes
         return self._query(requests.post, 'acting/start', nodes=nodes)
 
-    def start_sleeping(self, nodes: List = None) -> List[Dict[str, Any]]:
-        """
-        Tells all nodes to start sleeping.
-
-        TODO: Should user be able to specify which nodes.
-        """
-        if nodes is None:
-            nodes = self.all_nodes
-        return self._query(requests.post, 'sleeping/start', nodes=nodes)
-
     def stop_acting(self, nodes: List = None) -> List[Dict[str, Any]]:
         """
         Stop query nodes from acting.
-
-        TODO: Should user be able to specify which nodes.
         """
         if nodes is None:
             nodes = self.query_nodes
         return self._query(requests.post, 'acting/stop', nodes=nodes)
 
+    def start_sleeping(self, nodes: List = None) -> List[Dict[str, Any]]:
+        """
+        Tells all nodes to start sleeping.
+        """
+        if nodes is None:
+            nodes = self.all_nodes
+        return self._query(requests.post, 'sleeping/start', nodes=nodes)
+
     def stop_sleeping(self, nodes: List = None) -> List[Dict[str, Any]]:
         """
         Wakes up all sleeping nodes.
-
-        TODO: Should user be able to specify which nodes.
         """
         if nodes is None:
             nodes = self.all_nodes
         return self._query(requests.post, 'sleeping/stop', nodes=nodes)
 
+    def start_predicting(self, nodes: List = None) -> List[Dict[str, Any]]:
+        """
+        Tells all nodes to start predicting.
+        """
+        if nodes is None:
+            nodes = self.all_nodes
+        return self._query(requests.post, 'predicting/start', nodes=nodes)
+
+    def stop_predicting(self, nodes: List = None) -> List[Dict[str, Any]]:
+        """
+        Tells all nodes to stop predicting. Useful for faster training, but abstracted nodes will not learn.
+        """
+        if nodes is None:
+            nodes = self.all_nodes
+        return self._query(requests.post, 'predicting/stop', nodes=nodes)
+
     def ping(self, nodes: List = None) -> List[Dict[str, Any]]:
         """Ping a node to ensure it's up."""
         if nodes is None:
@@ -515,3 +518,37 @@ class BottleClient:
                 return response['message']
             results.append({node: response["message"]})
         return results
+
+    def analyze_kb(self, nodes: List = None) -> List[Dict[str, Any]]:
+        """
+        Kickstarts analysis for the selected primitives' KBs.
+        This is a long running process and can be monitored via kb_analysis_progress ('/kb/analysis-progress')
+        """
+        if nodes is None:
+            nodes = self.all_nodes
+        return self._query(requests.post, 'kb/analyze', nodes=nodes)
+    
+    def kb_analysis_progress(self): #, nodes: List = None) -> List[Dict[str, Any]]:
+        """
+        Monitors the KB analysis progress kickstarted by analyze_kb.
+        """
+        if not self._connected:
+            raise ConnectionError(
+                'Not connected to a bottle. You must call `connect()` on a BottleClient instance before making queries')
+        results = []
+        
+        response = requests.get(f'{self.url}kb/analysis-progress', verify=self.secure, json=[], headers=self.headers).json()
+        return response
+
+    def set_target_class(self, target_class: str = None, nodes: List = None) -> List:
+        """Provide a target_class symbol for the searcher to look for. It will ignore all other classes.
+        This is a symbol that is in the last event of a classification sequence."""
+        if nodes is None:
+            nodes = self.query_nodes
+        return self._query(requests.post, 'set-target-class', nodes=nodes, data=target_class)
+    
+    def clear_target_class(self, nodes: List = None) -> List:
+        "Clears target selection."
+        if nodes is None:
+            nodes = self.query_nodes
+        return self._query(requests.post, 'clear-target-class', nodes=nodes)
